@@ -69,6 +69,8 @@ from optax._src.lookahead import LookaheadParams
 from optax._src.lookahead import LookaheadState
 from optax._src.loss import cosine_distance
 from optax._src.loss import cosine_similarity
+from optax._src.loss import ctc_loss
+from optax._src.loss import ctc_loss_with_forward_probs
 from optax._src.loss import huber_loss
 from optax._src.loss import l2_loss
 from optax._src.loss import log_cosh
@@ -152,7 +154,7 @@ from optax._src.wrappers import MaybeUpdateState
 from optax._src.wrappers import MultiSteps
 from optax._src.wrappers import MultiStepsState
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 __all__ = (
     "adabelief",
@@ -181,6 +183,8 @@ __all__ = (
     "ClipByGlobalNormState",
     "ClipState",
     "constant_schedule",
+    "ctc_loss",
+    "ctc_loss_with_forward_probs",
     "control_delta_method",
     "control_variates_jacobians",
     "cosine_decay_schedule",
