@@ -257,7 +257,11 @@ def adamw(
       This is needed for instance when computing (meta-)gradients through Adam.
     mu_dtype: optional `dtype` to be used for the first order accumulator; if
       `None` then the `dtype` is inferred from `params` and `updates`.
-    weight_decay: strength of the weight decay regularization.
+    weight_decay: strength of the weight decay regularization. Note that this
+      weight decay is multiplied with the learning rate. This is consistent
+      with other frameworks such as PyTorch, but different from
+      (Loshchilov et al, 2019) where the weight decay is only multiplied with
+      the "schedule multiplier", but not the base learning rate.
     mask: a tree with same structure as (or a prefix of) the params PyTree,
       or a Callable that returns such a pytree given the params/updates.
       The leaves should be booleans, `True` for leaves/subtrees you want to
@@ -319,7 +323,7 @@ def lars(
 ) -> base.GradientTransformation:
   """The LARS optimiser.
 
-  LAMB is a layer-wise adaptive optimiser introduced to help scale SGD to
+  LARS is a layer-wise adaptive optimiser introduced to help scale SGD to
   larger batch sizes. LARS later inspired the LAMB optimiser.
 
   References:
