@@ -20,12 +20,13 @@ import jax.numpy as jnp
 import numpy as np
 
 from optax._src import base
+from optax._src import numerics
 
 
 def global_norm(updates: base.Updates) -> base.Updates:
   """Compute the global norm across a nested structure of tensors."""
   return jnp.sqrt(
-      sum([jnp.sum(jnp.square(x)) for x in jax.tree_leaves(updates)]))
+      sum([jnp.sum(numerics.abs_sq(x)) for x in jax.tree_leaves(updates)]))
 
 
 def power_iteration(
