@@ -122,7 +122,7 @@ def lookahead(
       # Jittable way of resetting the fast optimizer state if parameters will be
       # synchronized after this update step.
       initial_state = fast_optimizer.init(params.fast)
-      fast_state = jax.tree_multimap(
+      fast_state = jax.tree_map(
           lambda current, init: (1 - sync_next) * current + sync_next * init,
           fast_state, initial_state)
 
@@ -180,11 +180,11 @@ def _lookahead_update(
   #   slow_updates = slow_step_size * sync_next * last_difference
   #   fast_updates = updates - (
   #                  1 - slow_step_size) * sync_next * last_difference
-  last_difference = jax.tree_multimap(lambda f, u, s: f + u - s, params.fast,
-                                      updates, params.slow)
-  slow_updates = jax.tree_map(lambda diff: slow_step_size * sync_next * diff,
-                              last_difference)
-  fast_updates = jax.tree_multimap(
+  last_difference = jax.tree_map(
+      lambda f, u, s: f + u - s, params.fast, updates, params.slow)
+  slow_updates = jax.tree_map(
+      lambda diff: slow_step_size * sync_next * diff, last_difference)
+  fast_updates = jax.tree_map(
       lambda up, diff: up - sync_next * (1 - slow_step_size) * diff, updates,
       last_difference)
 
