@@ -14,6 +14,8 @@
 # ==============================================================================
 """Tests for `wrappers.py`."""
 
+import copy
+
 from absl.testing import absltest
 from absl.testing import parameterized
 
@@ -35,9 +37,11 @@ def _build_sgd():
   return alias.sgd(1.)
 
 
-def _build_simple_adam():
-  # This adam behaves like an sgd, but with state.
-  return alias.adam(1., b1=0., b2=0.)
+def _build_stateful_sgd():
+  # This SGD behaves like _build_sgd but also tests the optimizer state. The
+  # momentum is set to zero rather than None so that the momentum terms are
+  # calculated, but do not change the results.
+  return alias.sgd(1., momentum=0.)
 
 
 class WrappersTest(parameterized.TestCase):
@@ -69,7 +73,7 @@ class WrappersTest(parameterized.TestCase):
   @chex.variants(with_jit=True, without_jit=True, with_pmap=True)
   @parameterized.named_parameters(
       ('sgd', _build_sgd),
-      ('adam', _build_simple_adam),
+      ('stateful_sgd', _build_stateful_sgd),
   )
   def test_apply_if_finite(self, opt_builder):
     one = jnp.ones([])
@@ -204,7 +208,7 @@ class WrappersTest(parameterized.TestCase):
       if idx % k_steps < k_steps - 1:
         # The parameters should not have changed and the loss should be
         # constant.
-        jax.tree_multimap(np.testing.assert_array_equal, new_params, params)
+        jax.tree_map(np.testing.assert_array_equal, new_params, params)
         np.testing.assert_equal(new_loss, prev_loss)
         self.assertFalse(ms_opt.has_updated(opt_state))
       else:
@@ -262,10 +266,10 @@ class MaskedTest(chex.TestCase):
 
   @chex.all_variants
   @parameterized.named_parameters(
-      ('scale', lambda: transform.scale(-1.), True),  # stateless test
-      ('sgd', _build_sgd, False),  # stateful test
-      ('scale', lambda: transform.scale(-1.), True),  # stateless test
-      ('sgd', _build_sgd, False),  # stateful test
+      ('sgd', _build_sgd, False),
+      ('stateful_sgd', _build_stateful_sgd, False),
+      ('sgd_w_mask_fn', _build_sgd, True),
+      ('stateful_sgd_w_mask_fn', _build_stateful_sgd, True),
   )
   def test_masked(self, opt_builder, use_fn):
     mask = {'a': True,
@@ -278,7 +282,7 @@ class MaskedTest(chex.TestCase):
 
     # Negate the updates wherever the mask is True
     def masked_negate(updates):
-      return jax.tree_multimap(
+      return jax.tree_map(
           lambda upd, m: -upd if m else upd, updates, mask)
     correct_updates = masked_negate(input_updates)
 
@@ -295,8 +299,8 @@ class MaskedTest(chex.TestCase):
 
   @chex.all_variants
   @parameterized.named_parameters(
-      ('scale', lambda: transform.scale(-1.)),  # stateless test
-      ('sgd', _build_sgd),  # stateful test
+      ('sgd', _build_sgd),
+      ('stateful_sgd', _build_stateful_sgd),
   )
   def test_prefix_mask(self, opt_builder):
     """Test when the mask is a prefix of the updates PyTree."""
@@ -308,7 +312,7 @@ class MaskedTest(chex.TestCase):
     # Negate the updates wherever the mask (or mask parent) is True
     def _masked_sgd_on_updates(m, upd):
       return jax.tree_map(lambda x: -x, upd) if m else upd
-    correct_updates = jax.tree_multimap(
+    correct_updates = jax.tree_map(
         _masked_sgd_on_updates, mask, input_updates)
 
     init_fn, update_fn = wrappers.masked(opt_builder(), mask)
@@ -318,7 +322,7 @@ class MaskedTest(chex.TestCase):
     chex.assert_tree_all_close(updates, correct_updates)
 
     # Check repeated application, this time with no params.
-    correct_updates = jax.tree_multimap(
+    correct_updates = jax.tree_map(
         _masked_sgd_on_updates, mask, correct_updates)
     updates, state = update_fn(updates, state)
     chex.assert_tree_all_close(updates, correct_updates)
@@ -333,7 +337,7 @@ class MaskedTest(chex.TestCase):
     params = jax.tree_map(jnp.asarray, params)
     input_updates = jax.tree_map(lambda x: x/10., params)
 
-    correct_updates = jax.tree_multimap(
+    correct_updates = jax.tree_map(
         lambda m, u, p: u + weight_decay * p if m else u,
         mask, input_updates, params)
 
@@ -348,7 +352,7 @@ class MaskedTest(chex.TestCase):
     params = update.apply_updates(params, updates)
 
     # Test repeated application
-    new_correct_updates = jax.tree_multimap(
+    new_correct_updates = jax.tree_map(
         lambda m, u, p: u + weight_decay * p if m else u,
         mask, correct_updates, params)
     updates, state = update_fn(correct_updates, state, params)
@@ -394,6 +398,44 @@ class MaskedTest(chex.TestCase):
     np.testing.assert_allclose(updates['b'][1],
                                grads['b'][1] + 0.1*params['b'][1])
 
+  @chex.all_variants
+  @parameterized.named_parameters(
+      ('sgd', _build_sgd),
+      ('stateful_sgd', _build_stateful_sgd),
+  )
+  def test_nested_mask(self, opt_builder):
+    # https://github.com/deepmind/optax/issues/271
+    params = {'linear_1': {'w': jnp.zeros((1, 1)), 'b': jnp.zeros(1)},
+              'linear_2': {'w': jnp.zeros((1, 2)), 'b': jnp.zeros(2)},
+              'linear_3': {'w': jnp.zeros((2, 3)), 'b': jnp.zeros(3)}}
+
+    outer_mask = lambda p: jax.tree_map(lambda x: x.ndim > 1, p)
+    inner_mask = jax.tree_map(lambda _: True, params)
+    inner_mask['linear_2'] = False
+
+    inner = wrappers.masked(opt_builder(), inner_mask)
+    init_fn, update_fn = wrappers.masked(inner, outer_mask)
+
+    input_updates = jax.tree_map(jnp.ones_like, params)
+    correct_updates = copy.deepcopy(input_updates)
+    correct_updates['linear_1']['w'] *= -1.0
+    correct_updates['linear_3']['w'] *= -1.0
+
+    state = self.variant(init_fn)(params)
+    updates, state = self.variant(update_fn)(input_updates, state, params)
+    chex.assert_trees_all_close(updates, correct_updates)
+
+  @chex.all_variants
+  def test_masked_state_structure(self):
+    # https://github.com/deepmind/optax/issues/271
+    params = {'a': [jnp.ones(1), (jnp.ones(2), jnp.ones(3))],
+              'b': {'c': jnp.ones(4), 'd': jnp.ones(5)}}
+    mask = {'a': [True, (True, False)], 'b': False}
+    tx = wrappers.masked(_build_stateful_sgd(), mask)
+    trace = self.variant(tx.init)(params).inner_state[0].trace
+    expected_trace = {'a': [jnp.zeros(1), (jnp.zeros(2), None)], 'b': None}
+    chex.assert_tree_all_equal_structs(trace, expected_trace)
+
 
 class MaybeUpdateTest(chex.TestCase):
   """Tests for the maybe_update wrapper."""
